AngularJS ui-select

# Getting started

### Dependencies

This repository contains a native AngularJS select directive based on Bootstrap/Select2/Selectize's CSS. As a result no dependency on jQuery or 3rd-Party JavaScript is required. The only required dependencies are:

- AngularJS (requires AngularJS 1.2.x or higher, tested with 1.5.3).
- Angular-Sanitze (the version should match your version of angular.js).
- The matching CSS for your the theme you wish to use:
  - Bootstrap
  - Select2
  - Selectize

### Installation

#### Install via npm

    $ npm install ui-select

#### Install via bower

    $ bower install angular-ui-select

As soon as you've got all the files downloaded and included in your page you just need to declare a dependency on the `ui.select` module:

    angular.module('myModule', ['ui.select', 'ngSanitize']);

# Documentation

### Wiki

For up to date information please refer to the Wiki

### FAQ

Please check our FAQ section for common problems / solutions.

# Examples

You can fork one of the plunkers from this page to see a working example of what is described here.